@@ -42,3 +42,8 @@ void ExerciseDialog::start()
 
     emit close();
 }
+
+void ExerciseDialog::closeEvent(QCloseEvent *event)
+{
+    return event->ignore();
+}
