@@ -5,7 +5,6 @@ HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
 {
     QString set;
     setAttribute(Qt::WA_Maemo5StackedWindow);
-    setAttribute(Qt::WA_Maemo5PortraitOrientation);
 
     QWidget *widget = new QWidget();
     QVBoxLayout *vLayout = new QVBoxLayout();
@@ -30,9 +29,6 @@ void HistoryInfoWindow::load(QString name, QString group, QString date)
     int j = 0;
     QString set;
 
-    if(name.right(1) == " ")
-        name = name.left(name.count() - 1);
-
     setWindowTitle(name);
 
     list = xml->getHistoryByExercise(name, date);
@@ -40,7 +36,6 @@ void HistoryInfoWindow::load(QString name, QString group, QString date)
     if(list.isEmpty())
         return;
 
-    qDebug () << "HistoryInfoWindow::load loop start";
     while(!list.isEmpty())
     {
         set.setNum(j+1);
@@ -53,15 +48,10 @@ void HistoryInfoWindow::load(QString name, QString group, QString date)
         else
         {
             list.removeFirst();
-            qDebug () << "HistoryInfoWindow::load a";
             list.removeFirst();
-            qDebug () << "HistoryInfoWindow::load b";
             list.removeFirst();
-            qDebug () << "HistoryInfoWindow::load c";
         }
 
         j++;
     }
-
-    qDebug () << "HistoryInfoWindow::load end";
 }
